==> webkitgtk-2.39.5.tar.xz: webkitgtk-2.39.5/Source/WebGPU/WGSL/AST/AST.h <==
/*
 * Copyright (C) 2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ASTArrayAccess.h"
#include "ASTAssignmentStatement.h"
#include "ASTAttribute.h"
#include "ASTBindingAttribute.h"
#include "ASTBuiltinAttribute.h"
#include "ASTCallableExpression.h"
#include "ASTCompoundStatement.h"
#include "ASTDecl.h"
#include "ASTExpression.h"
#include "ASTFunctionDecl.h"
#include "ASTGlobalDirective.h"
#include "ASTGroupAttribute.h"
#include "ASTIdentifierExpression.h"
#include "ASTLiteralExpressions.h"
#include "ASTLocationAttribute.h"
#include "ASTNode.h"
#include "ASTReturnStatement.h"
#include "ASTShaderModule.h"
#include "ASTStageAttribute.h"
#include "ASTStatement.h"
#include "ASTStructureAccess.h"
#include "ASTStructureDecl.h"
#include "ASTTypeDecl.h"
#include "ASTUnaryExpression.h"
#include "ASTVariableDecl.h"
#include "ASTVariableQualifier.h"
#include "ASTVariableStatement.h"

==> webkitgtk-2.39.7.tar.xz: webkitgtk-2.39.7/Source/WebGPU/WGSL/AST/AST.h <==
/*
 * Copyright (C) 2022 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "ASTArrayAccess.h"
#include "ASTAssignmentStatement.h"
#include "ASTAttribute.h"
#include "ASTBinaryExpression.h"
#include "ASTBindingAttribute.h"
#include "ASTBuiltinAttribute.h"
#include "ASTCallableExpression.h"
#include "ASTCompoundStatement.h"
#include "ASTDecl.h"
#include "ASTExpression.h"
#include "ASTFunctionDecl.h"
#include "ASTGlobalDirective.h"
#include "ASTGroupAttribute.h"
#include "ASTIdentifierExpression.h"
#include "ASTIdentityExpression.h"
#include "ASTLiteralExpressions.h"
#include "ASTLocationAttribute.h"
#include "ASTNode.h"
#include "ASTPointerDereference.h"
#include "ASTReturnStatement.h"
#include "ASTShaderModule.h"
#include "ASTStageAttribute.h"
#include "ASTStatement.h"
#include "ASTStructureAccess.h"
#include "ASTStructureDecl.h"
#include "ASTTypeDecl.h"
#include "ASTUnaryExpression.h"
#include "ASTVariableDecl.h"
#include "ASTVariableQualifier.h"
#include "ASTVariableStatement.h"
#include "ASTWorkgroupSizeAttribute.h"
